import 'dart:convert';

import 'package:api_package/api_package.dart';
import 'package:intl/intl.dart';
import 'package:validators/validators.dart';

class Argument {
  static final DateFormat _dateFormat = DateFormat("YYYY-mm-dd");

  final String? value;
  final String argName;
  final ifNull;

  Argument(this.value, this.argName, {this.ifNull}) {
    if(value == null) {
      if (ifNull == null) {
        throw ApiError.wrongParams(argName);
      }
    } else if (value!.isEmpty) {
      throw ApiError.wrongParams(argName);
    }
  }

  DateTime toDateTime() {
    if (value == null) {
      assert(ifNull is DateTime);
      return ifNull;
    }
    try {
      return _dateFormat.parse(value!);
    } on FormatException catch (_) {
      throw ApiError.wrongParams(argName);
    }
  }

  int toInt() {
    if (value == null) {
      assert(ifNull is int);
      return ifNull;
    }
    try {
      return int.parse(value!);
    } on FormatException catch (_) {
      throw ApiError.wrongParams(argName);
    }
  }

  double toDouble() {
    if (value == null) {
      assert(ifNull is double);
      return ifNull;
    }
    try {
      return double.parse(value!);
    } on FormatException catch (_) {
      throw ApiError.wrongParams(argName);
    }
  }

  String toUuid() {
    if (value == null) {
      assert (ifNull is String);
      return ifNull;
    }
    if (!isUUID(value))
      throw ApiError.wrongParams(argName);
    return value!;
  }

  List<int> toIntList() {
    if (value == null) {
      assert(ifNull is List<int>);
      return ifNull;
    }
    try {
      return (jsonDecode(value!) as List).cast<int>();
    } catch (error, stacktrace) {
      if (Env.debug) {
        print(error);
        print(stacktrace);
      }
      throw ApiError.wrongParams(argName);
    }
  }

  Map<String, dynamic> toJsonMap() {
    if (value == null) {
      assert(ifNull is Map<String, dynamic>);
      return ifNull;
    }
    try {
      return (jsonDecode(value!) as Map).cast<String, dynamic>();
    } catch (error, stacktrace) {
      if (Env.debug) {
        print(error);
        print(stacktrace);
      }
      throw ApiError.wrongParams(argName);
    }
  }

  @override
  String toString() {
    if (value == null) {
      assert (ifNull is String);
      return ifNull;
    }
    return value!;
  }
}