
import 'dart:io';
import 'package:api_package/api_package.dart';
import 'package:shelf/shelf.dart';

class Auth {
  late final String token;
  late final int tokenId, userId;

  Auth(Request request) {
    String? token = request.headers[HttpHeaders.authorizationHeader];
    if (token == null || token.isEmpty) {
      throw ApiError.tokenMissing;
    }
    this.token = token;
  }

  Future<void> auth(Database db, AuthHandler handler, [List<dynamic>? params]) async {
    // possible exceptions get caught by errorHandler() in ApiError.dart
    TokenData? data = await handler(db, token, params);
    if (data == null)
      throw ApiError.tokenInvalid;
    userId = data.userId;
    tokenId = data.tokenId;
  }

  Future<void> checkPerm(Database db) async {
    // TODO
  }
}

typedef AuthHandler = Future<TokenData?> Function(Database db, String token, List<dynamic>? params);

class TokenData {
  final int userId, tokenId;
  TokenData(this.userId, this.tokenId);
}