import 'dart:io';

/// Checks and handles the environment variables
class Env {
  static final get = Env._();
  static final Map<String, String> _envVars = Platform.environment;

  static bool get debug => Env.get.appVersion == "development";

  // app
  final String appVersion;

  // webserver
  final String webserverHost;
  int webserverPort;

  // database
  final String pgHost, pgUser, pgPassword, pgDatabase;
  final int pgPort;

  Env._()
      : pgHost = _envVars['PG_HOST'] ?? "localhost",
        pgPort = int.parse(_envVars['PG_PORT'] ?? "3306"),
        pgUser = _envVars['PG_USER'] ??
            (throw ArgumentError("Environment variable PG_USER not set.")),
        pgPassword = _envVars['PG_PASS'] ??
            (throw ArgumentError("Environment variable PG_PASS not set.")),
        pgDatabase = _envVars['PG_DB'] ??
            (throw ArgumentError("Environment variable PG_DB not set.")),
        appVersion = _envVars['APP_VERSION'] ?? "development",
        webserverHost = _envVars['WEBSERVER_HOST'] ?? "0.0.0.0",
        webserverPort = int.parse(_envVars['WEBSERVER_PORT'] ?? "8080");
}