import 'dart:io';

import 'package:api_package/api_package.dart';
import 'package:shelf/shelf.dart';
import 'package:test/expect.dart';
import 'package:test/scaffolding.dart';

class MyApiData extends ApiData {
  final int? index;

  MyApiData([this.index]);

  @override
  Map<String, dynamic> toJson() => {
    "number": this.index,
    "string": "test 😀",
    "bool": true,
  };
}

void main() {
  test("Create and build ApiData Response", () {
    MyApiData data = MyApiData();

    Response response = data.build(cache: null);
    expect(response.statusCode, 200);
    expect(response.isEmpty, false);
    expect(response.headers[HttpHeaders.cacheControlHeader], contains("no-cache"));

    response = data.build(cache: Duration(minutes: 10), etag: "etag");
    expect(response.headers[HttpHeaders.cacheControlHeader], contains("max-age="));
    expect(response.headers[HttpHeaders.etagHeader], equals("etag"));
  });

  test("Create and build List<ApiData> Response", () {
    List<MyApiData> list = List.generate(2, (index) => MyApiData(index));
    Response response = list.build(cache: null);
    expect(response.statusCode, 200);
  });

  test("Test ApiError", () {
    ApiError error = ApiError.accessDenied;
    expect(error.error, "access_denied");

    Response response = error.build();
    expect(response.statusCode, 403);
  });
}
